@@ -8,9 +8,9 @@ from os import linesep
 from sys import getsizeof
 from ._check import check_var, raise_
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -42,9 +42,8 @@ class Data(FrozenClass):
         )
     else:
         _set_normalizations = _set_normalizations
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
 
     def __init__(
         self,
@@ -226,6 +225,28 @@ class Data(FrozenClass):
         Data_dict["__class__"] = "Data"
         return Data_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        symbol_val = self.symbol
+        name_val = self.name
+        unit_val = self.unit
+        if self.normalizations is None:
+            normalizations_val = None
+        else:
+            normalizations_val = dict()
+            for key, obj in self.normalizations.items():
+                normalizations_val[key] = obj.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            symbol=symbol_val,
+            name=name_val,
+            unit=unit_val,
+            normalizations=normalizations_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except SciDataTool object)"""
 
