@@ -6,7 +6,7 @@ from SciDataTool.Functions.Plot import fft_dict, ifft_dict
 
 
 def plot_2D_Data_Animated(
-    self, animated_axis, *param_list, nb_frames=50, fps=10, **param_dict
+    self, animated_axis, suptitle_ref, *param_list, nb_frames=50, fps=10, **param_dict
 ):
     """Gen
 
@@ -47,9 +47,11 @@ def plot_2D_Data_Animated(
         animated_axis = animated_axis.split("[")[0] + animated_axis_unit
 
     if "freqs" in param_list or "wavenumber" in param_list:
-        result = self.get_magnitude_along(animated_axis, *param_list)
+        result = self.get_magnitude_along(
+            animated_axis, *param_list, unit=param_dict["unit"]
+        )
     else:
-        result = self.get_along(animated_axis, *param_list)
+        result = self.get_along(animated_axis, *param_list, unit=param_dict["unit"])
 
     animated_axis_unit = "{" + animated_axis.split("{")[1]
     animated_axis = animated_axis.split("{")[0].split("[")[0]
@@ -69,14 +71,17 @@ def plot_2D_Data_Animated(
         frames_list = arange(start=value_min, stop=value_max, step=variation_step)
         frames_list = ["=" + str(frame) for frame in frames_list]
 
-    # Setting the options of the plot
-    y_max = nanmax(result[self.symbol])
-    y_min = nanmin(result[self.symbol])
-    marge = (
-        y_max - y_min
-    ) * 0.05  # 5% of the height of plot to add to the border top/bottom of gif
-    plot_options["y_min"] = nanmin(result[self.symbol]) - abs(marge)
-    plot_options["y_max"] = nanmax(result[self.symbol]) + abs(marge)
+    # detecting if we are animating a regular plot (=> computing limit for y) or a "fft" plot (=> limit already set)
+    if plot_options["y_min"] == None or plot_options["y_max"] == None:
+        # Setting the options of the plot
+        y_max = nanmax(result[self.symbol])
+        y_min = nanmin(result[self.symbol])
+        marge = (
+            y_max - y_min
+        ) * 0.05  # 5% of the height of plot to add to the border top/bottom of gif
+        plot_options["y_min"] = nanmin(result[self.symbol]) - abs(marge)
+        plot_options["y_max"] = nanmax(result[self.symbol]) + abs(marge)
+
     plot_options["is_show_fig"] = False
 
     # Getting the name of the gif
@@ -91,6 +96,11 @@ def plot_2D_Data_Animated(
         )
         # Getting the figure generated with plot_2D_DATA
         fig = plt.gcf()
+
+        # Adding the suptitle of the figure if there is one
+        if suptitle_ref != "":
+            fig.suptitle(suptitle_ref)
+
         fig.canvas.draw()
         image = frombuffer(fig.canvas.tostring_rgb(), dtype="uint8")
         image = image.reshape(fig.canvas.get_width_height()[::-1] + (3,))
